# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['plumes']

package_data = \
{'': ['*']}

install_requires = \
['dynaconf>=3.1.0,<4.0.0',
 'fire>=0.3.1,<0.4.0',
 'python-box>=5.1.0,<6.0.0',
 'toml>=0.10.1,<0.11.0',
 'tqdm>=4.48.2,<5.0.0',
 'tweepy>=3.9.0,<4.0.0']

entry_points = \
{'console_scripts': ['plumes = plumes.cli:main']}

setup_kwargs = {
    'name': 'plumes',
    'version': '1.2.1',
    'description': 'Simple Twitter CLI for day-to-day social media hygiene',
    'long_description': '<br />\n<p align="center">\n  <a href="https://github.com/nnadeau/plumes">\n    <img src="https://raw.githubusercontent.com/nnadeau/plumes/master/media/feather.png" alt="Logo" width="80" height="80">\n  </a>\n\n  <h3 align="center">plumes</h3>\n\n  <p align="center">\n    Simple Twitter CLI for day-to-day social media hygiene\n    <br />\n    ·\n    <a href="https://github.com/nnadeau/plumes/issues">Report Bug</a>\n    ·\n    <a href="https://github.com/nnadeau/plumes/issues">Request Feature</a>\n  </p>\n</p>\n\n[![GitHub issues](https://img.shields.io/github/issues/nnadeau/plumes)](https://github.com/nnadeau/plumes/issues)\n[![GitHub forks](https://img.shields.io/github/forks/nnadeau/plumes)](https://github.com/nnadeau/plumes/network)\n[![GitHub stars](https://img.shields.io/github/stars/nnadeau/plumes)](https://github.com/nnadeau/plumes/stargazers)\n[![GitHub license](https://img.shields.io/github/license/nnadeau/plumes)](https://github.com/nnadeau/plumes/blob/master/LICENSE)\n\n[![PyPI Version](https://img.shields.io/pypi/v/plumes.svg)](https://pypi.python.org/pypi/plumes)\n[![PyPI License](https://img.shields.io/pypi/l/plumes.svg)](https://pypi.python.org/pypi/plumes)\n[![PyPI Wheel](https://img.shields.io/pypi/wheel/plumes.svg)](https://pypi.python.org/pypi/plumes)\n[![PyPI Format](https://img.shields.io/pypi/format/plumes.svg)](https://pypi.python.org/pypi/plumes)\n[![PyPI Pythons](https://img.shields.io/pypi/pyversions/plumes.svg)](https://pypi.python.org/pypi/plumes)\n[![PyPI Implementation](https://img.shields.io/pypi/implementation/plumes.svg)](https://pypi.python.org/pypi/plumes)\n\n[![semantic-release](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg)](https://github.com/semantic-release/semantic-release)\n[![Test](https://github.com/nnadeau/plumes/workflows/Test/badge.svg)](https://github.com/nnadeau/plumes/actions)\n[![Release](https://github.com/nnadeau/plumes/workflows/Release/badge.svg)](https://github.com/nnadeau/plumes/actions)\n[![Publish](https://github.com/nnadeau/plumes/workflows/Publish/badge.svg)](https://github.com/nnadeau/plumes/actions)\n\n[![Twitter](https://img.shields.io/twitter/url?style=social&url=https%3A%2F%2Fgithub.com%2Fnnadeau%2Fplumes)](https://twitter.com/intent/tweet?text=Wow:&url=https%3A%2F%2Fgithub.com%2Fnnadeau%2Fplumes)\n\n## Contents\n\n- [Contents](#contents)\n- [Overview](#overview)\n- [Inspiration](#inspiration)\n- [Installation](#installation)\n- [Usage](#usage)\n  - [Getting Started And Creating Your Authentication Config](#getting-started-and-creating-your-authentication-config)\n  - [Export Your Friends](#export-your-friends)\n  - [Export Your Followers](#export-your-followers)\n  - [Export Your Tweets](#export-your-tweets)\n  - [Prune Your Friends](#prune-your-friends)\n  - [Prune Your Tweets](#prune-your-tweets)\n- [Setting Up Authentication](#setting-up-authentication)\n  - [Get Your Twitter API Tokens](#get-your-twitter-api-tokens)\n  - [Configuring `plumes`](#configuring-plumes)\n- [Contributing](#contributing)\n- [Testing](#testing)\n\n## Overview\n\n`Plumes` is an open-source Python CLI app for day-to-day social media hygiene.\nIt was designed to provide a simple, clear, and concise interface to quickly explore and clean a personal Twitter account.\n\n## Inspiration\n\n[![panzer tweet](https://raw.githubusercontent.com/nnadeau/plumes/master/media/tweet-panzer.png)](https://twitter.com/panzer/status/943935357673861120)\n\n[![chrisalbon tweet](https://raw.githubusercontent.com/nnadeau/plumes/master/media/tweet-chrisalbon.png)](https://twitter.com/chrisalbon/status/1295408107078615041)\n\n\n## Installation\n\n```bash\n# python >=3.6.1 is required\npip install plumes\n```\n\n## Usage\n\n### Getting Started And Creating Your Authentication Config\n\n```bash\n# create your config file\nplumes init\n```\n\n### Export Your Friends\n\nExtract friends ordered in which they were added:\n\n```bash\nplumes friends <flags>\n```\n\n- Optional flags:\n  - `--screen_name`: alternative user (defaults to yourself)\n  - `--limit`: max number of users to export\n  - `--output`: alternative output path\n\n![Plumes friends gif](https://raw.githubusercontent.com/nnadeau/plumes/master/media/terminal-friends.gif)\n\n### Export Your Followers\n\nExtract followers ordered in which they were added:\n\n```bash\nplumes followers <flags>\n```\n\n- Optional flags:\n  - `--screen_name`: alternative user (defaults to yourself)\n  - `--limit`: max number of users to export\n  - `--output`: alternative output path\n\n### Export Your Tweets\n\nExtract tweets ordered in by most recent:\n\n```bash\nplumes tweets <flags>\n```\n\n- Optional flags:\n  - `--screen_name`: alternative user (defaults to yourself)\n  - `--limit`: max number of tweets to export\n  - `--output`: alternative output path\n\n![Plumes tweet gif](https://raw.githubusercontent.com/nnadeau/plumes/master/media/terminal-tweets.gif)\n\n### Prune Your Friends\n\n```bash\nplumes prune_friends PATH <flags>\n\n# e.g.,\nplumes friends --output "friends.json"\nplumes prune_friends "friends.json" --min_followers 100 --execute\n```\n\n- `PATH`: path to JSON file exported from `plumes friends`\n- Optional flags:\n  - `--execute`: actually perform the pruning process, else a dry-run is performed\n  - `--days`: prune by number of days since last tweeted\n  - `--min_followers` / `--max_followers`: prune by number of followers\n  - `--min_friends` / `--max_friends`: prune by number of friends\n  - `--min_tweets` / `--max_tweets`: prune by number of tweets\n  - `--min_ratio` / `--max_ratio`: prune by Twitter follower-friend (TFF) ratio\n\n![Prune friends gif](https://raw.githubusercontent.com/nnadeau/plumes/master/media/terminal-prune-friends.gif)\n\n### Prune Your Tweets\n\n```bash\nplumes prune_tweets PATH <flags>\n\n# e.g.,\nplumes tweets --output "tweets.json"\nplumes prune_tweets "tweets.json" --days 60 --protect_favorited --execute\n```\n\n- `PATH`: path to JSON file exported from `plumes tweets`\n- Optional flags:\n  - `--execute`: actually perform the pruning process, else a dry-run is performed\n  - `--days`: prune age of tweet\n  - `--protect_favorited`: don\'t prune self-liked tweets\n  - `--min_likes` / `--max_likes`: prune by number of likes\n  - `--min_retweets` / `--max_retweets`: prune by number of retweets\n  - `--min_ratio` / `--max_ratio`: prune by Twitter like-retweet ratio\n\n## Setting Up Authentication\n\n### Get Your Twitter API Tokens\n\n- Navigate to the [Twitter Dev Portal](https://developer.twitter.com/en/apps)\n- Click `Create an app`\n\n  ![Twitter app link](https://raw.githubusercontent.com/nnadeau/plumes/master/media/2020-08-20-09-11-05.png)\n\n- Fill out the forms\n- Navigate to `Keys and tokens`\n\n  ![Tokens link](https://raw.githubusercontent.com/nnadeau/plumes/master/media/2020-08-20-09-12-34.png)\n\n- Copy the values for `API key`, `API secret key`, `Access token`, and `Access token secret`\n\n  ![Keys and tokens](https://raw.githubusercontent.com/nnadeau/plumes/master/media/2020-08-20-09-13-24.png)\n\n### Configuring `plumes`\n\nThe API tokens can either be set as environment variables (using the `PLUMES_` prefix; e.g., `export PLUMES_CONSUMER_KEY=xxxxx`) or configuration variables in `~/.plumes.toml`:\n\n- CONSUMER_KEY = `<API key>`\n- CONSUMER_SECRET = `<API secret key>`\n- ACCESS_TOKEN = `<Access token>`\n- ACCESS_TOKEN_SECRET = `<Access token secret>`\n\n## Contributing\n\nPlease see [`CONTRIBUTING.md`](.github/CONTRIBUTING.md) and the [Code of Conduct](CODE_OF_CONDUCT.md) for how to contribute to the project\n\n## Testing\n\n- Please review the [`Makefile`](Makefile) for an overview of all available tests\n- The most important tests and `make` commands are highlighted below:\n\n```bash\n# auto-format code\nmake format\n\n# perform all static tests\nmake check\n```\n\n---\n\n<div>Icons made by <a href="https://smashicons.com/" title="Smashicons">Smashicons</a> from <a href="https://www.flaticon.com/" title="Flaticon">www.flaticon.com</a></div>\n',
    'author': 'Nicholas Nadeau',
    'author_email': 'nicholas.nadeau@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/nnadeau/plumes',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6.1,<4.0.0',
}


setup(**setup_kwargs)
